ams.opt.optbase.OptzBase
========================

.. currentmodule:: ams.opt.optbase

.. autoclass:: OptzBase

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~OptzBase.evaluate
       
       
          ~OptzBase.parse
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~OptzBase.class_name
      ~OptzBase.n
      ~OptzBase.shape
      ~OptzBase.size
   
   